@@ -1,4 +1,5 @@
 """Generates plots for usage in documentation"""
+
 from pathlib import Path
 
 import matplotlib.pyplot as plt
@@ -66,19 +67,19 @@ def make_gasoil_endpoints(show=True, krgendanchor="sorg"):
     axes.annotate(
         "KROMAX",
         xy=(0, kromax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(0.1, kromax + 0.07),
     )
     axes.annotate(
         "KROEND",
         xy=(sgro, kroend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(sgro + 0.07, kroend + 0.05),
     )
     axes.annotate(
         "KRGEND",
         xy=(1 - sorg - swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sorg - swl + 0.01, krgmax - 0.2),
     )
     # Overwrite with same text at identical spots for
@@ -86,36 +87,36 @@ def make_gasoil_endpoints(show=True, krgendanchor="sorg"):
     axes.annotate(
         "KRGEND",
         xy=(1 - swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sorg - swl + 0.01, krgmax - 0.2),
     )
     axes.annotate(
         "KRGMAX",
         xy=(1 - swl, krgmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - swl - 0.2, krgmax + 0.1),
     )
     axes.text(0.0, 0.07, "SGCR")
     axes.annotate(
-        "", xy=(-0.01, 0.04), xytext=(sgcr, 0.04), arrowprops=dict(arrowstyle="<->")
+        "", xy=(-0.01, 0.04), xytext=(sgcr, 0.04), arrowprops={"arrowstyle": "<->"}
     )
     axes.text(0.0, 0.73, "SGRO")
     axes.annotate(
         "",
         xy=(-0.01, kroend - 0.02),
         xytext=(sgro, kroend - 0.02),
-        arrowprops=dict(arrowstyle="<->"),
+        arrowprops={"arrowstyle": "<->"},
     )
     plt.xlabel("SG", labelpad=-10)
     axes.annotate(
         "",
         xy=(1 - sorg - swl, 0.02),
         xytext=(1 - swl, 0.02),
-        arrowprops=dict(arrowstyle="<->"),
+        arrowprops={"arrowstyle": "<->"},
     )
     axes.text(1 - sorg - swl + 0.04, 0.04, "SORG")
     axes.annotate(
-        "", xy=(1 - swl, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - swl, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
     axes.text(1 - swl + 0.04, 0.04, "SWL")
     axes.legend(loc="upper center")
@@ -149,42 +150,42 @@ def make_wateroil_endpoints(show=True):
     axes.annotate(
         "KROEND",
         xy=(swl, kroend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.1, kroend - 0.3),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sorw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sorw - 0.09, krwmax - 0.2),
     )
     axes.annotate(
         "KRWMAX",
         xy=(1, krwmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.1, krwmax - 0.3),
     )
     axes.annotate(
         "SWIRR",
         xy=(swirr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swirr - 0.12, 0 + 0.1),
     )
     axes.annotate(
         "SWL",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.05, 0 + 0.14),
     )
     axes.annotate(
         "SWCR",
         xy=(swcr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swcr - 0.06, 0 + 0.21),
     )
     plt.xlabel("SW", labelpad=-10)
     axes.annotate(
-        "", xy=(1 - sorw, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sorw, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
     axes.text(1 - sorw + 0.04, 0.04, "SORW")
     if show:
@@ -218,49 +219,49 @@ def make_gaswater_endpoints(show=True):
     axes.annotate(
         "KRGEND",
         xy=(swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.1, krgend - 0.3),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sgrw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sgrw - 0.23, krwmax - 0.2),
     )
     axes.annotate(
         "KRWMAX",
         xy=(1, krwmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.1, krwmax - 0.3),
     )
     axes.annotate(
         "SWIRR",
         xy=(swirr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swirr - 0.12, 0 + 0.1),
     )
     axes.annotate(
         "SWL",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.05, 0 + 0.14),
     )
     axes.annotate(
         "SWCR",
         xy=(swcr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swcr - 0.06, 0 + 0.21),
     )
     plt.xlabel("SW", labelpad=-10)
 
     axes.text(1 - sgrw + 0.04, 0.04, "SGRW")
     axes.annotate(
-        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
 
     axes.text(1 - sgcr + 0.04, 0.14, "SGCR")
     axes.annotate(
-        "", xy=(1 - sgcr, 0.12), xytext=(1, 0.12), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgcr, 0.12), xytext=(1, 0.12), arrowprops={"arrowstyle": "<->"}
     )
 
     if show:
@@ -293,37 +294,37 @@ def make_wateroil_idc2(show=True):
     axes.annotate(
         "KROEND",
         xy=(swl, kroend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl + 0.1, kroend + 0.1),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sorw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.15, krwend - 0.02),
     )
     axes.annotate(
         "KRWMAX",
         xy=(1, krwmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.3, krwmax - 0.02),
     )
     axes.annotate(
         "SWIRR",
         xy=(swirr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swirr - 0.12, 0 + 0.1),
     )
     axes.annotate(
         "SWL≈SWCR",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.055, 0 + 0.14),
     )
     plt.xlabel("SW", labelpad=-10)
     axes.legend(loc="upper center")
     axes.annotate(
-        "", xy=(1 - sorw, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sorw, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
     axes.text(1 - sorw + 0.04, 0.04, "SORW")
 
@@ -377,25 +378,25 @@ def make_gasoil_cdi2(show=True):
     axes.annotate(
         "KROEND",
         xy=(0, kroend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(0.1, kroend + 0.02),
     )
     axes.annotate(
         "KRGEND",
         xy=(1 - sorg - swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.2, krgend - 0.02),
     )
     axes.annotate(
         "KRGMAX",
         xy=(1 - swl, krgmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.35, krgmax - 0.04),
     )
     axes.annotate(
         "SGCR",
         xy=(sgcr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(sgcr - 0.05, 0 + 0.14),
     )
     plt.xlabel("SG", labelpad=-10)
@@ -403,11 +404,11 @@ def make_gasoil_cdi2(show=True):
         "",
         xy=(1 - sorg - swl, 0.02),
         xytext=(1 - swl, 0.02),
-        arrowprops=dict(arrowstyle="<->"),
+        arrowprops={"arrowstyle": "<->"},
     )
     axes.text(1 - sorg - swl + 0.04, 0.04, "SORG")
     axes.annotate(
-        "", xy=(1 - swl, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - swl, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
     axes.text(1 - swl + 0.04, 0.04, "SWL")
     axes.legend(loc="upper center")
@@ -463,25 +464,25 @@ def make_gasoil_cid2(show=True):
     axes.annotate(
         "KROEND",
         xy=(sgro, kroend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(sgro + 0.1, kroend - 0.05),
     )
     axes.annotate(
         "KROMAX",
         xy=(0, kromax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(0.1, kromax + 0.05),
     )
     axes.annotate(
         "KRGEND",
         xy=(1 - swl, krgend - 0.01),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.35, krgend - 0.04),
     )
     axes.annotate(
         "SGCR=SGRO",
         xy=(sgcr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(sgcr - 0.1, 0 + 0.14),
     )
     plt.xlabel("SG", labelpad=-10)
@@ -489,11 +490,11 @@ def make_gasoil_cid2(show=True):
         "",
         xy=(1 - sorg - swl, 0.08),
         xytext=(1 - swl, 0.08),
-        arrowprops=dict(arrowstyle="<->"),
+        arrowprops={"arrowstyle": "<->"},
     )
     axes.text(1 - sorg - swl + 0.02, 0.1, "SORG")
     axes.annotate(
-        "", xy=(1 - swl, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - swl, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
     axes.text(1 - swl + 0.04, 0.04, "SWL")
     axes.legend(loc="upper center")
@@ -547,43 +548,43 @@ def make_gaswater_icd2(show=True):
     axes.annotate(
         "KRGEND",
         xy=(swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl + 0.1, krgend - 0.1),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sgrw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sgrw - 0.23, krwmax - 0.1),
     )
     axes.annotate(
         "KRWMAX",
         xy=(1 - 0.01, krwmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.23, krwmax),
     )
     axes.annotate(
         "SWL",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.07, 0 + 0.12),
     )
     axes.annotate(
         "SWCR",
         xy=(swcr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swcr - 0.06, 0 + 0.21),
     )
     plt.xlabel("SW", labelpad=-10)
 
     axes.text(1 - sgrw + 0.04, 0.04, "SGRW")
     axes.annotate(
-        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
 
     axes.text(1 - sgcr + 0.04, 0.14, "SGCR")
     axes.annotate(
-        "", xy=(1 - sgcr, 0.12), xytext=(1, 0.12), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgcr, 0.12), xytext=(1, 0.12), arrowprops={"arrowstyle": "<->"}
     )
 
     # Initial state and saturation direction:
@@ -637,31 +638,31 @@ def make_gaswater_dci1(show=True):
     axes.annotate(
         "KRGEND",
         xy=(swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl + 0.1, krgend - 0.1),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sgrw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sgrw - 0.23, krwend - 0.1),
     )
     axes.annotate(
         "SWL=SWCR",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.08, 0 + 0.1),
     )
     plt.xlabel("SW", labelpad=-10)
 
     # axes.text(1 - sgrw + 0.04, 0.04, "SGRW")
     axes.annotate(
-        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
 
     axes.text(1 - sgcr + 0.04, 0.14, "SGCR")
     axes.annotate(
-        "", xy=(1 - sgcr, 0.12), xytext=(1, 0.12), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgcr, 0.12), xytext=(1, 0.12), arrowprops={"arrowstyle": "<->"}
     )
 
     # Initial state and saturation direction:
@@ -717,32 +718,32 @@ def make_gaswater_co2_icd2(show=True):
     axes.annotate(
         "KRGEND",
         xy=(swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl + 0.1, krgend - 0.1),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sgrw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sgrw - 0.23, krwend + 0.1),
     )
     axes.annotate(
         "KRWMAX",
         xy=(1, krwmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.23, krwmax - 0.1),
     )
     axes.annotate(
         "SWL=SWCR",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.1, 0 + 0.1),
     )
     plt.xlabel("SW", labelpad=-10)
 
     axes.text(1 - sgrw + 0.04, 0.04, "SGRW=SGCR")
     axes.annotate(
-        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgrw, 0.02), xytext=(1, 0.02), arrowprops={"arrowstyle": "<->"}
     )
 
     # Initial state and saturation direction:
@@ -797,43 +798,43 @@ def make_wateroil_paleooil_idc1(show=True):
     axes.annotate(
         "KROEND",
         xy=(swl, kroend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl + 0.07, kroend),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sorw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sorw - 0.15, krwend + 0.05),
     )
     axes.annotate(
         "KRWMAX",
         xy=(1, krwmax),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - 0.25, krwmax - 0.05),
     )
     axes.annotate(
         "SWL",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.05, 0 + 0.14),
     )
     axes.annotate(
         "SWCR",
         xy=(swcr, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swcr - 0.06, 0 + 0.21),
     )
     plt.xlabel("SW", labelpad=-10)
     axes.annotate(
-        "", xy=(1 - sorw, krwend), xytext=(1, krwend), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sorw, krwend), xytext=(1, krwend), arrowprops={"arrowstyle": "<->"}
     )
     axes.text(1 - sorw + 0.03, krwend - 0.05, "SORW")
     axes.annotate(
         "",
         xy=(1 - socr, 0.12),
         xytext=(1, 0.12),
-        arrowprops=dict(arrowstyle="<->"),
+        arrowprops={"arrowstyle": "<->"},
     )
     axes.text(1 - socr + 0.05, 0.14, "SOCR")
     axes.legend(loc="upper center")
@@ -889,19 +890,19 @@ def make_gaswater_paleogas_dci3(show=True):
     axes.annotate(
         "KRGEND",
         xy=(swl, krgend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.1, krgend - 0.3),
     )
     axes.annotate(
         "KRWEND",
         xy=(1 - sgrw, krwend),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(1 - sgrw - 0.23, krwend - 0.1),
     )
     axes.annotate(
         "SWL=SWCR",
         xy=(swl, 0),
-        arrowprops=dict(arrowstyle="->"),
+        arrowprops={"arrowstyle": "->"},
         xytext=(swl - 0.1, 0 + 0.14),
     )
     plt.xlabel("SW", labelpad=-10)
@@ -909,17 +910,17 @@ def make_gaswater_paleogas_dci3(show=True):
 
     axes.text(1 - sgrw + 0.01, krwend - 0.05, "SGRW")
     axes.annotate(
-        "", xy=(1 - sgrw, krwend), xytext=(1, krwend), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgrw, krwend), xytext=(1, krwend), arrowprops={"arrowstyle": "<->"}
     )
 
     axes.text(1 - sgcr + 0.04, 0.09, "SGCR")
     axes.annotate(
-        "", xy=(1 - sgcr, 0.07), xytext=(1, 0.07), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgcr, 0.07), xytext=(1, 0.07), arrowprops={"arrowstyle": "<->"}
     )
 
     axes.text(1 - sgl + 0.02, 0.02, "SGL")
     axes.annotate(
-        "", xy=(1 - sgl, 0.00), xytext=(1, 0.00), arrowprops=dict(arrowstyle="<->")
+        "", xy=(1 - sgl, 0.00), xytext=(1, 0.00), arrowprops={"arrowstyle": "<->"}
     )
 
     # Initial state and saturation direction:
