@@ -1,4 +1,5 @@
 """Test module for GasOil objects"""
+
 import io
 import sys
 
@@ -11,7 +12,7 @@ import pytest
 from hypothesis import given
 
 from pyscal import GasOil
-from pyscal.constants import MAX_EXPONENT, SWINTEGERS
+from pyscal.constants import MAX_EXPONENT_KR, SWINTEGERS
 from pyscal.utils.relperm import truncate_zeroness
 from pyscal.utils.testing import (
     check_linear_sections,
@@ -69,12 +70,12 @@ def test_gasoil_init():
     # Test too small h:
     gasoil = GasOil(swl=0.1, h=0.00000000000000000001)
     # (a warning is printed that h is truncated)
-    assert gasoil.h == 1 / SWINTEGERS
+    assert gasoil.h == 10 / SWINTEGERS
 
 
 def test_conserve_sgcr(mocker):
     """sgcr in the table can be hard to conserve"""
-    low_sgcrvalue = 0.00001  # 1/10 of 1/SWINTEGERS
+    low_sgcrvalue = 1 / SWINTEGERS / 10
     # Verify the default behaviour of truncation:
     assert truncate_zeroness(low_sgcrvalue) == 0
     mocker.patch(
@@ -158,7 +159,7 @@ def test_gasoil_normalization(swl, sgcr, sorg, h, tag):
         swirr=0.0, swl=swl, sgcr=sgcr, sorg=sorg, h=h, krgendanchor="sorg", tag=tag
     )
     assert not gasoil.table.empty
-    assert not gasoil.table.isnull().values.any()
+    assert not gasoil.table.isna().to_numpy().any()
 
     # Check that son is 1 at sg=0
     assert float_df_checker(gasoil.table, "SG", 0, "SON", 1)
@@ -198,10 +199,7 @@ def test_gasoil_krendmax(
     swl, sgcr, sorg, sgrononzero, kroend, kromax, krgend, krgmax, h, fast
 ):
     """Test that relperm curves are valid in all numerical corner cases."""
-    if sgrononzero:
-        sgro = sgcr
-    else:
-        sgro = 0
+    sgro = sgcr if sgrononzero else 0
     try:
         assert 1 - sorg - swl - sgcr > 1 / SWINTEGERS, "No saturation range left"
         gasoil = GasOil(
@@ -303,10 +301,12 @@ def test_gasoil_krgendanchor():
 
     # kg should be 1.0 at 1 - sorg due to krgendanchor == "sorg":
     assert (
-        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].values[0]
+        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].to_numpy()[
+            0
+        ]
         == 1.0
     )
-    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].values[0] == 1.0
+    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].to_numpy()[0] == 1.0
 
     gasoil = GasOil(krgendanchor="", sorg=0.2, h=0.1)
     assert gasoil.sorg
@@ -315,10 +315,12 @@ def test_gasoil_krgendanchor():
 
     # kg should be < 1 at 1 - sorg due to krgendanchor being ""
     assert (
-        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].values[0]
+        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].to_numpy()[
+            0
+        ]
         < 1.0
     )
-    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].values[0] == 1.0
+    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].to_numpy()[0] == 1.0
     assert gasoil.selfcheck()
     assert gasoil.crosspoint() > 0
 
@@ -332,10 +334,12 @@ def test_gasoil_krgendanchor():
 
     # kg should be 1.0 at 1 - sorg due to krgendanchor == "sorg":
     assert (
-        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].values[0]
+        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].to_numpy()[
+            0
+        ]
         == 1.0
     )
-    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].values[0] == 1.0
+    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].to_numpy()[0] == 1.0
 
     gasoil = GasOil(krgendanchor="", sorg=0.2, h=0.1)
     assert gasoil.sorg
@@ -346,10 +350,12 @@ def test_gasoil_krgendanchor():
 
     # kg should be < 1 at 1 - sorg due to krgendanchor being ""
     assert (
-        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].values[0]
+        gasoil.table[np.isclose(gasoil.table["SG"], 1 - gasoil.sorg)]["KRG"].to_numpy()[
+            0
+        ]
         < 1.0
     )
-    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].values[0] == 1.0
+    assert gasoil.table[np.isclose(gasoil.table["SG"], 1.0)]["KRG"].to_numpy()[0] == 1.0
 
 
 def test_nexus():
@@ -369,9 +375,8 @@ def test_nexus():
         sep=r"\s+",
         header=None,
     )
-    # pylint: disable=no-member  # false positive on Pandas dataframe
-    assert (df.values <= 1.0).all()
-    assert (df.values >= 0.0).all()
+    assert (df.to_numpy() <= 1.0).all()
+    assert (df.to_numpy() >= 0.0).all()
 
 
 def test_linearsegments():
@@ -403,8 +408,8 @@ def test_kroend():
 
 
 @given(
-    st.floats(min_value=1e-4, max_value=MAX_EXPONENT),  # ng
-    st.floats(min_value=1e-4, max_value=MAX_EXPONENT),  # nog
+    st.floats(min_value=1e-4, max_value=MAX_EXPONENT_KR),  # ng
+    st.floats(min_value=1e-4, max_value=MAX_EXPONENT_KR),  # nog
 )
 def test_gasoil_corey1(ng, nog):
     """Test the Corey formulation for gasoil"""
@@ -606,5 +611,5 @@ def test_selfcheck(columnname, errorvalues):
     gasoil.table[columnname] = errorvalues
     assert not gasoil.selfcheck()
     assert gasoil.SGOF() == ""
-    if not columnname == "KROG":
+    if columnname != "KROG":
         assert gasoil.SGFN() == ""
