@@ -10,7 +10,8 @@ import numpy as np
 import pytest
 from matplotlib import pyplot
 
-from pyscal import GasOil, GasWater, PyscalFactory, WaterOil, utils
+from pyscal import GasOil, GasWater, WaterOil, utils
+from pyscal.factory import create_scal_recommendation
 
 from .test_scalrecommendation import BASE_SAMPLE_LET, HIGH_SAMPLE_LET, LOW_SAMPLE_LET
 
@@ -176,14 +177,8 @@ def test_interpolate_go():
     kromax_h = random.uniform(0.5, 1)
     kroend_l = min(random.uniform(0.5, 1), kromax_l)
     kroend_h = min(random.uniform(0.5, 1), kromax_h)
-    if random.uniform(0, 1) > 0.5:
-        krgendanchor_l = "sorg"
-    else:
-        krgendanchor_l = ""
-    if random.uniform(0, 1) > 0.5:
-        krgendanchor_h = "sorg"
-    else:
-        krgendanchor_h = ""
+    krgendanchor_l = "sorg" if random.uniform(0, 1) > 0.5 else ""
+    krgendanchor_h = "sorg" if random.uniform(0, 1) > 0.5 else ""
     go_low = GasOil(
         swl=swl_l,
         sgcr=sgcr_l,
@@ -243,7 +238,6 @@ def test_interpolate_go():
 @pytest.mark.parametrize("", [(), (), ()])  # 3 repeated runs
 def test_interpolate_gw():
     """Discrete test scenarios for gaswater interpolation"""
-    # pylint: disable=too-many-locals
     swl_l = random.uniform(0, 0.1)
     swcr_l = swl_l + random.uniform(0, 0.1)
     sgrw_l = random.uniform(0, 0.2)
@@ -310,10 +304,9 @@ def test_interpolate_gw():
 @pytest.mark.plot
 def test_SCAL_interpolation():
     """Demonstration of interpolation between LET curves, 2x2 subplot"""
-    # pylint: disable=invalid-name
     matplotlib.style.use("ggplot")
 
-    rec = PyscalFactory.create_scal_recommendation(
+    rec = create_scal_recommendation(
         {"low": LOW_SAMPLE_LET, "base": BASE_SAMPLE_LET, "high": HIGH_SAMPLE_LET},
         "FOO",
         h=0.001,
