@@ -20,7 +20,6 @@ def test_installed():
     assert subprocess.check_output(["pyscal", "-h"])
 
 
-@pytest.mark.skipif(sys.platform == "win32", reason="UTF-8 problems on Windows")
 @pytest.mark.skipif(sys.version_info < (3, 7), reason="Requires Python 3.7 or higher")
 @pytest.mark.parametrize("verbosity_flag", [None, "--verbose", "--debug"])
 def test_log_levels(tmp_path, verbosity_flag):
@@ -29,9 +28,7 @@ def test_log_levels(tmp_path, verbosity_flag):
 
     relperm_file = str(
         # A cell in this xlsx contains "Åre 1.5", does not work on Windows
-        Path(__file__).absolute().parent
-        / "data"
-        / "relperm-input-example.xlsx"
+        Path(__file__).absolute().parent / "data" / "relperm-input-example.xlsx"
     )
 
     commands = ["pyscal", relperm_file]
@@ -59,7 +56,6 @@ def test_log_levels(tmp_path, verbosity_flag):
 
 
 def test_pyscal_client_static(tmp_path, caplog, default_loglevel, mocker):
-    # pylint: disable=unused-argument
     # default_loglevel fixture is in conftest.py
     """Test pyscal client for static relperm input"""
     testdir = Path(__file__).absolute().parent
@@ -143,17 +139,17 @@ def test_pyscal_client_static(tmp_path, caplog, default_loglevel, mocker):
             "eclipse/include/props/relperm-fam2.inc",
         ],
     )
-    pyscalcli.main()
-    assert Path("eclipse/include/props/relperm-fam2.inc").is_file()
-    assert not any(record.levelno == logging.ERROR for record in caplog.records)
+    with pytest.raises(SystemExit, match="Output directory not found"):
+        pyscalcli.main()
+    assert not Path("eclipse/include/props/relperm-fam2.inc").is_file()
 
     caplog.clear()
     mocker.patch(
         "sys.argv", ["pyscal", str(relperm_file), "-o", "include/props/relperm.inc"]
     )
-    pyscalcli.main()
-    assert Path("include/props/relperm.inc").is_file()
-    assert not any(record.levelno == logging.ERROR for record in caplog.records)
+    with pytest.raises(SystemExit, match="Output directory not found"):
+        pyscalcli.main()
+    assert not Path("include/props/relperm.inc").is_file()
 
     caplog.clear()
     # Check that we can read specific sheets
@@ -314,7 +310,6 @@ def test_pyscalcli_exception_catching(capsys, mocker):
     assert "raise" in outerr  # This is the traceback.
 
 
-@pytest.mark.skipif(sys.platform == "win32", reason="UTF-8 problems on Windows")
 def test_pyscalcli_oilwater(tmp_path, caplog, mocker):
     """Test the command line client in two-phase oil-water"""
     os.chdir(tmp_path)
@@ -323,7 +318,7 @@ def test_pyscalcli_oilwater(tmp_path, caplog, mocker):
         # "fooå" here causes problems on Windows
         columns=["SATNUM", "nw", "now", "tag"],
         data=[[1, 2, 3, "fooå"]],
-    ).to_csv(relperm_file, index=False)
+    ).to_csv(relperm_file, index=False, encoding="utf-8-sig")
     caplog.clear()
     mocker.patch(
         "sys.argv",
@@ -439,8 +434,6 @@ def test_pyscalcli_gaswater_scal(tmp_path, caplog, mocker):
 
 
 def test_pyscal_client_scal(tmp_path, caplog, default_loglevel, mocker):
-    # pylint: disable=unused-argument
-    # default_loglevel fixture is in conftest.py
     """Test the command line endpoint on SCAL recommendation"""
     scalrec_file = Path(__file__).absolute().parent / "data/scal-pc-input-example.xlsx"
 
@@ -588,3 +581,44 @@ def test_pyscal_main():
 
     with pytest.raises(ValueError, match="Interpolation parameter provided"):
         pyscalcli.pyscal_main(relperm_file, int_param_wo=-1, output=os.devnull)
+
+
+def test_pyscalcli_plot(capsys, mocker, tmpdir):
+    """Test that plots are created through the CLI. This is done by testing to
+    see if the print statements in the save_figure function are present in stdout"""
+    scalrec_file = Path(__file__).absolute().parent / "data/scal-pc-input-example.xlsx"
+
+    mocker.patch(
+        "sys.argv",
+        [
+            "pyscal",
+            str(scalrec_file),
+            "--int_param_wo",
+            "0",
+            "--output",
+            "-",
+            "--plot",
+            "--plot_pc",
+            "--plot_outdir",
+            str(tmpdir),
+        ],
+    )
+
+    pyscalcli.main()
+
+    expected_plots = [
+        "krw_krow_SATNUM_1.png",
+        "krg_krog_SATNUM_1.png",
+        "krw_krow_SATNUM_2.png",
+        "krg_krog_SATNUM_2.png",
+        "krw_krow_SATNUM_3.png",
+        "krg_krog_SATNUM_3.png",
+        "pcow_SATNUM_1.png",
+        "pcow_SATNUM_2.png",
+        "pcow_SATNUM_3.png",
+    ]
+
+    captured = capsys.readouterr()
+
+    for plot in expected_plots:
+        assert plot in captured.out
