@@ -13,7 +13,7 @@ from pyscal.utils.testing import sat_table_str_ok
 def check_table(dframe):
     """Check sanity of important columns"""
     assert not dframe.empty
-    assert not dframe.isnull().values.any()
+    assert not dframe.isna().to_numpy().any()
     assert dframe["SL"].is_monotonic_increasing
     assert (dframe["SL"] >= 0.0).all()
     assert (dframe["SL"] <= 1.0).all()
@@ -49,12 +49,12 @@ def test_slgof(swl, sorg, sgcr):
     sat_table_str_ok(wog.SLGOF())
 
     # Requirements from E100 manual:
-    assert np.isclose(slgof["SL"].values[0], wog.gasoil.swl + wog.gasoil.sorg)
-    assert np.isclose(slgof["KRG"].values[-1], 0)
-    assert np.isclose(slgof["KROG"].values[0], 0)
+    assert np.isclose(slgof["SL"].to_numpy()[0], wog.gasoil.swl + wog.gasoil.sorg)
+    assert np.isclose(slgof["KRG"].to_numpy()[-1], 0)
+    assert np.isclose(slgof["KROG"].to_numpy()[0], 0)
 
     # If we ruin the object, SLGOF() will return an empty string:
-    wog.gasoil.table.drop("KRG", axis="columns", inplace=True)
+    wog.gasoil.table = wog.gasoil.table.drop("KRG", axis="columns")
     assert wog.gasoil.SLGOF() == ""
     assert wog.SLGOF() == ""
 
@@ -72,7 +72,6 @@ def test_slgof(swl, sorg, sgcr):
         (1e-12, 0.0, 0.1),
         (1e-11, 0.0, 0.1),
         (1e-10, 0.0, 0.1),
-        #
         (0.1, 0.0, 0.1),
         (0.1, 1e-18, 0.1),
         (0.1, 1e-17, 0.1),
@@ -83,7 +82,6 @@ def test_slgof(swl, sorg, sgcr):
         (0.1, 1e-12, 0.1),
         (0.1, 1e-11, 0.1),
         (0.1, 1e-10, 0.1),
-        #
         (0.1, 0.0, 0.0),
         (0.1, 0.0, 1e-18),
         (0.1, 0.0, 1e-17),
@@ -94,7 +92,6 @@ def test_slgof(swl, sorg, sgcr):
         (0.1, 0.0, 1e-12),
         (0.1, 0.0, 1e-11),
         (0.1, 0.0, 1e-10),
-        #
         (0.1 - 0.0, 0.0, 0.1),
         (0.1 - 1e-18, 0.0, 0.1),
         (0.1 - 1e-17, 0.0, 0.1),
@@ -119,8 +116,8 @@ def test_numerical_problems(swl, sorg, sgcr):
     gasoil.add_corey_oil()
     assert gasoil.selfcheck()
     slgof = gasoil.slgof_df()
-    assert np.isclose(slgof["SL"].values[0], gasoil.swl + gasoil.sorg)
-    assert np.isclose(slgof["SL"].values[-1], 1.0)
+    assert np.isclose(slgof["SL"].to_numpy()[0], gasoil.swl + gasoil.sorg)
+    assert np.isclose(slgof["SL"].to_numpy()[-1], 1.0)
     check_table(slgof)
 
 
@@ -128,7 +125,7 @@ def test_numerical_problems(swl, sorg, sgcr):
     st.floats(min_value=0.0, max_value=0.3),
     st.floats(min_value=0.0, max_value=0.3),
     st.floats(min_value=0.0, max_value=0.3),
-    st.floats(min_value=1.0 / float(1000 * SWINTEGERS), max_value=0.5),
+    st.floats(min_value=1.0 / SWINTEGERS, max_value=0.5),
 )
 def test_slgof_hypo(swl, sorg, sgcr, h):
     """Shotgun-testing of slgof"""
@@ -139,9 +136,9 @@ def test_slgof_hypo(swl, sorg, sgcr, h):
     slgof = gasoil.slgof_df()
     check_table(slgof)
     # Eclipse 100 requirement from manual:
-    assert np.isclose(slgof["SL"].values[0], gasoil.swl + gasoil.sorg)
+    assert np.isclose(slgof["SL"].to_numpy()[0], gasoil.swl + gasoil.sorg)
     # Eclipse 100 requirement from manual:
-    assert np.isclose(slgof["SL"].values[-1], 1.0)
+    assert np.isclose(slgof["SL"].to_numpy()[-1], 1.0)
     slgof_str = gasoil.SLGOF()
     assert isinstance(slgof_str, str)
     assert slgof_str
@@ -151,7 +148,7 @@ def test_slgof_hypo(swl, sorg, sgcr, h):
 @given(
     st.floats(min_value=0.0, max_value=0.3),
     st.floats(min_value=0.0, max_value=0.3),
-    st.floats(min_value=1.0 / float(1000 * SWINTEGERS), max_value=0.5),
+    st.floats(min_value=1.0 / float(100 * SWINTEGERS), max_value=0.5),
 )
 def test_slgof_sl_mismatch(swl, sorg, h):
     """Test numerical robustness on slgof table creation."""
@@ -161,4 +158,6 @@ def test_slgof_sl_mismatch(swl, sorg, h):
 
     # It is a strict requirement that the first sl value should be swl + sorg,
     # but GasOil might have truncated the values.
-    assert np.isclose(gasoil.slgof_df()["SL"].values[0] - (gasoil.swl + gasoil.sorg), 0)
+    assert np.isclose(
+        gasoil.slgof_df()["SL"].to_numpy()[0] - (gasoil.swl + gasoil.sorg), 0
+    )
