@@ -1,4 +1,5 @@
 """Test module for the WaterOil object"""
+
 import io
 import sys
 
@@ -296,9 +297,8 @@ def test_nexus():
         sep=r"\s+",
         header=None,
     )
-    # pylint: disable=no-member  # false positive on Pandas dataframe
-    assert (df.values <= 1.0).all()
-    assert (df.values >= 0.0).all()
+    assert (df.to_numpy() <= 1.0).all()
+    assert (df.to_numpy() >= 0.0).all()
 
 
 @pytest.mark.parametrize(
@@ -327,5 +327,5 @@ def test_selfcheck(columnname, errorvalues):
     wateroil.table[columnname] = errorvalues
     assert not wateroil.selfcheck()
     assert wateroil.SWOF() == ""
-    if not columnname == "KROW":
+    if columnname != "KROW":
         assert wateroil.SWFN() == ""
